Paper Games API
===============

This section documents the API for all paper-and-pencil game modules.

Tic-Tac-Toe
-----------

Classic Tic-Tac-Toe with minimax AI and various board sizes.

.. automodule:: paper_games.tic_tac_toe.tic_tac_toe
   :members:
   :undoc-members:
   :show-inheritance:

Ultimate Tic-Tac-Toe
~~~~~~~~~~~~~~~~~~~~

Implementation of Ultimate Tic-Tac-Toe variant.

.. automodule:: paper_games.tic_tac_toe.ultimate
   :members:
   :undoc-members:
   :show-inheritance:

Battleship
----------

Naval combat game with ship placement and AI opponent.

.. automodule:: paper_games.battleship.battleship
   :members:
   :undoc-members:
   :show-inheritance:

Battleship GUI
~~~~~~~~~~~~~~

Graphical user interface for Battleship.

.. automodule:: paper_games.battleship.gui
   :members:
   :undoc-members:
   :show-inheritance:

Battleship PyQt GUI
~~~~~~~~~~~~~~~~~~~

PyQt5 graphical user interface for Battleship.

.. automodule:: paper_games.battleship.gui_pyqt
   :members:
   :undoc-members:
   :show-inheritance:

Dots and Boxes
--------------

Connect the dots to complete boxes and score points.

.. automodule:: paper_games.dots_and_boxes.dots_and_boxes
   :members:
   :undoc-members:
   :show-inheritance:

Hangman
-------

Word guessing game with ASCII art gallows.

.. automodule:: paper_games.hangman.hangman
   :members:
   :undoc-members:
   :show-inheritance:

Nim
---

Mathematical strategy game with multiple variants.

.. automodule:: paper_games.nim.nim
   :members:
   :undoc-members:
   :show-inheritance:

Nim Variants
~~~~~~~~~~~~

Additional Nim game variants (Northcott's Game, Wythoff's Game).

.. automodule:: paper_games.nim.variants
   :members:
   :undoc-members:
   :show-inheritance:

Unscramble
----------

Word unscrambling game with scoring.

.. automodule:: paper_games.unscramble.unscramble
   :members:
   :undoc-members:
   :show-inheritance:
